import React from 'react';
export declare type ProSchemaValueEnumType = {
    /** @name 演示的文案 */
    text: React.ReactNode;
    /** @name 预定的颜色 */
    status?: string;
    /** @name 自定义的颜色 */
    color?: string;
    /** @name 是否禁用 */
    disabled?: boolean;
};
/**
 * 支持 Map 和 Object
 *
 * @name ValueEnum 的类型
 */
declare type ProSchemaValueEnumMap = Map<React.ReactText, ProSchemaValueEnumType | React.ReactNode>;
declare type ProSchemaValueEnumObj = Record<string, ProSchemaValueEnumType | React.ReactNode>;
export declare type BaseProFieldFC = {
    /** 值的类型 */
    text: React.ReactNode;
    /** 放置到组件上 props */
    fieldProps?: any;
    /** 模式类型 */
    mode: ProFieldFCMode;
    /** 简约模式 */
    plain?: boolean;
    /** 轻量模式 */
    light?: boolean;
    /** Label */
    label?: React.ReactNode;
    /** 映射值的类型 */
    valueEnum?: ProSchemaValueEnumObj | ProSchemaValueEnumMap;
    /** 唯一的key，用于网络请求 */
    proFieldKey?: React.Key;
};
export declare type ProFieldFCMode = 'read' | 'edit' | 'update';
/** Render 第二个参数，里面包含了一些常用的参数 */
export declare type ProFieldFCRenderProps = {
    mode?: ProFieldFCMode;
    readonly?: boolean;
    placeholder?: string | string[];
    value?: any;
    onChange?: (...rest: any[]) => void;
} & BaseProFieldFC;
export declare type ProRenderFieldPropsType = {
    render?: ((text: any, props: Omit<ProFieldFCRenderProps, 'value' | 'onChange'>, dom: JSX.Element) => JSX.Element) | undefined;
    renderFormItem?: ((text: any, props: ProFieldFCRenderProps, dom: JSX.Element) => JSX.Element) | undefined;
};
export declare type IntlType = {
    locale: string;
    getMessage: (id: string, defaultMessage: string) => string;
};
/**
 * 创建一个操作函数
 *
 * @param locale
 * @param localeMap
 */
export declare const createIntl: (locale: string, localeMap: Record<string, any>) => IntlType;
declare const mnMNIntl: IntlType;
declare const arEGIntl: IntlType;
declare const zhCNIntl: IntlType;
declare const enUSIntl: IntlType;
declare const enGBIntl: IntlType;
declare const viVNIntl: IntlType;
declare const itITIntl: IntlType;
declare const jaJPIntl: IntlType;
declare const esESIntl: IntlType;
declare const caESIntl: IntlType;
declare const ruRUIntl: IntlType;
declare const srRSIntl: IntlType;
declare const msMYIntl: IntlType;
declare const zhTWIntl: IntlType;
declare const frFRIntl: IntlType;
declare const ptBRIntl: IntlType;
declare const koKRIntl: IntlType;
declare const idIDIntl: IntlType;
declare const deDEIntl: IntlType;
declare const faIRIntl: IntlType;
declare const trTRIntl: IntlType;
declare const plPLIntl: IntlType;
declare const hrHRIntl: IntlType;
declare const intlMap: {
    'mn-MN': IntlType;
    'ar-EG': IntlType;
    'zh-CN': IntlType;
    'en-US': IntlType;
    'en-GB': IntlType;
    'vi-VN': IntlType;
    'it-IT': IntlType;
    'ja-JP': IntlType;
    'es-ES': IntlType;
    'ca-ES': IntlType;
    'ru-RU': IntlType;
    'sr-RS': IntlType;
    'ms-MY': IntlType;
    'zh-TW': IntlType;
    'fr-FR': IntlType;
    'pt-BR': IntlType;
    'ko-KR': IntlType;
    'id-ID': IntlType;
    'de-DE': IntlType;
    'fa-IR': IntlType;
    'tr-TR': IntlType;
    'pl-PL': IntlType;
    'hr-HR': IntlType;
};
declare const intlMapKeys: string[];
export declare type ParamsType = Record<string, any>;
export { mnMNIntl, arEGIntl, enUSIntl, enGBIntl, zhCNIntl, viVNIntl, itITIntl, jaJPIntl, esESIntl, caESIntl, ruRUIntl, srRSIntl, msMYIntl, zhTWIntl, frFRIntl, ptBRIntl, koKRIntl, idIDIntl, deDEIntl, faIRIntl, trTRIntl, plPLIntl, hrHRIntl, intlMap, intlMapKeys, };
export declare type ConfigContextPropsType = {
    intl: IntlType;
    valueTypeMap: Record<string, ProRenderFieldPropsType>;
};
declare const ConfigContext: React.Context<ConfigContextPropsType>;
export declare const ConfigConsumer: React.Consumer<ConfigContextPropsType>, ConfigProvider: React.Provider<ConfigContextPropsType>;
/**
 * 如果没有配置 locale，这里组件会根据 antd 的 key 来自动选择
 *
 * @param param0
 */
export declare const ConfigProviderWrap: React.FC<Record<string, unknown>>;
export declare function useIntl(): IntlType;
export declare const ProProvider: React.Context<ConfigContextPropsType>;
export default ConfigContext;
